## cdist-type__group(7)

### Steven Armstrong

`<steven-cdist--@--armstrong.cc>`

## 1. NAME

cdist-type__group - Manage groups

## 2. DESCRIPTION

This cdist type allows you to create or modify groups on the target.

## 3. REQUIRED PARAMETERS

None.

## 4. OPTIONAL PARAMETERS

state
  absent or present, defaults to present
gid
  see groupmod(8)
password
  see above

## 5. BOOLEAN PARAMETERS

system
  see groupadd(8), apply only on group creation

## 6. MESSAGES

mod
  group is modified
add
  New group added
remove
  group is removed
change <property> <new_value> <current_value>
  Changed group property from current_value to new_value
set <property> <new_value>
  set property to new value, property was not set bevore

## 7. EXAMPLES

    # Create a group 'foobar' with operating system default settings
    __group foobar

    # Remove the 'foobar' group
    __group foobar --state absent

    # Create a system group 'myservice' with operating system default settings
    __group myservice --system

    # Same but with a specific gid
    __group foobar --gid 1234

    # Same but with a gid and password
    __group foobar --gid 1234 --password 'crypted-password-string'

## 8. SEE ALSO

- cdist-type(7)

## 9. COPYING

Copyright (C) 2011-2015 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).